libuuid: Universally Unique Identifier library
==============================================

Description
-----------

API for the generation of Universally Unique Identifiers (UUID).


Upstream Contact
----------------

http://www.ossp.org/pkg/lib/uuid/
